 /* public header file for NS-Link driver  */


struct rpshsi_config {
	int	line;
	int	flags;
	int	closing_wait;
	int	close_delay;
	int	port;
};

struct rpshsi_load_struct {
	unsigned long	offset;
	unsigned long	size;
	unsigned char	*buf;
};

/*
 * Maximum number of boxes
 */
#define MAX_NRP_SIS		64

/*
 * Maximum number of ports for a box
 */
#define MAX_NRP_PORTS	32

struct rpshsi_box_config {
	int		boxid;
        int             base_port;
	int		num_ports;
	int		state;
	unsigned char	ether_addr[6];
	char		interface[16];
	unsigned long ip_addr;
	unsigned char	rsmode[MAX_NRP_PORTS];
        int             link_timeout;
        int             arch_id;
        unsigned char   scan_period;
        int low_latency[MAX_NRP_PORTS];
        int inter_char_timeout[MAX_NRP_PORTS];
};

struct rpshsi_box_report {
	unsigned char	ether_addr[6];
	int		product_id;
	int		flags;
};

/*
 * MAC connected device structure
 */
struct si_mac_set {
	int				boxid;
};

/*
 * TCP connected device structures.
 */

struct si_tcp_set {
	int				boxid;
	int				sk;
	int				rbuf_size;
	unsigned char	*rbuf;
	int				wbuf_size;
	unsigned char	*wbuf;
};


typedef struct {
	unsigned char	cmd;
	unsigned char	index;
	unsigned short	length;
	unsigned long	addr;
} __attribute__((packed)) tToolRequest;

#define LOAD_TOOLREQ	1
#define GET_TOOLREQ	2
#define GOTO_TOOLREQ	3
#define MOVE_TOOLREQ	4
#define ID_TOOLREQ	5
#define SET_TOOLREQ	6
#define ENV_TOOLREQ	7
#define PING_TOOLREQ	8
#define DATA_TOOLREQ	9
#define SET_IP_TOOLREQ  10
#define ERASE_IP_TOOLREQ 11
#define DISABLE_IP_TOOLREQ 12
#define RESET_TOOLREQ   13

struct mac_id_response 
{
  unsigned char	MacAddr[6]        __attribute__((packed));
  unsigned char flags             __attribute__((packed));
  unsigned char unused[3]         __attribute__((packed));
  unsigned long   ModelId         __attribute__((packed));
  unsigned char   ArchId          __attribute__((packed));
  unsigned char   NumPorts        __attribute__((packed));
  unsigned short  ProgramId       __attribute__((packed));
  unsigned char   BoardRev        __attribute__((packed));
  unsigned char   BootRevMajor    __attribute__((packed));
  unsigned char   BootRevMinor    __attribute__((packed));
  unsigned char   NumApps         __attribute__((packed));
  struct 
    {
      unsigned short AppId        __attribute__((packed));
      unsigned char  AppRevMajor  __attribute__((packed));
      unsigned char  AppRevMinor  __attribute__((packed));
    }AppRecord[0]                __attribute__((packed));
  unsigned char   UserDataCount;
  unsigned char   UserData[0];
};

typedef struct
{
  unsigned long	IpAddr            __attribute__((packed));
  unsigned long	DefaultRoute      __attribute__((packed));
  unsigned long	ServerIpAddr      __attribute__((packed));
  unsigned long	SubnetMask        __attribute__((packed));
  unsigned long	AvailMemAddr      __attribute__((packed));
  unsigned long	AvailMemLength    __attribute__((packed));
  unsigned char	Version[64]       __attribute__((packed));
  unsigned char	MacAddr[6]        __attribute__((packed));
  unsigned long   ModelId         __attribute__((packed));
  unsigned char   ArchId          __attribute__((packed));
  unsigned char   NumPorts        __attribute__((packed));
  unsigned short  ProgramId       __attribute__((packed));
  unsigned char   BoardRev        __attribute__((packed));
  unsigned char   BootRevMajor    __attribute__((packed));
  unsigned char   BootRevMinor    __attribute__((packed));
  unsigned char   NumApps         __attribute__((packed));
  struct 
    {
      unsigned short AppId        __attribute__((packed));
      unsigned char  AppRevMajor  __attribute__((packed));
      unsigned char  AppRevMinor  __attribute__((packed));
    }AppRecord[0]                __attribute__((packed));
  unsigned char   UserDataCount;
  unsigned char   UserData[0];
} __attribute__((packed)) tToolResponse;

typedef struct
{
  unsigned long	IpAddr            __attribute__((packed));
  unsigned long	DefaultRoute      __attribute__((packed));
  unsigned long	ServerIpAddr      __attribute__((packed));
  unsigned long	SubnetMask        __attribute__((packed));
  unsigned long	AvailMemAddr      __attribute__((packed));
  unsigned long	AvailMemLength    __attribute__((packed));
  unsigned char	Version[64]       __attribute__((packed));
  unsigned char	MacAddr[6]        __attribute__((packed));
}  __attribute__((packed)) tOldToolResponse;;

/*
 * Rocketport flags
 */
#define RPSHSI_CALLOUT_NOHUP    0x00000001
#define RPSHSI_FORCE_CD		0x00000002
#define RPSHSI_HUP_NOTIFY	0x00000004
#define RPSHSI_SPLIT_TERMIOS	0x00000008
#define RPSHSI_SPD_MASK		0x00000070
#define RPSHSI_SPD_HI		0x00000010 /* Use 56000 instead of 38400 bps */
#define RPSHSI_SPD_VHI		0x00000020 /* Use 115200 instead of 38400 bps*/
#define RPSHSI_SPD_SHI		0x00000030 /* Use 230400 instead of 38400 bps*/
#define RPSHSI_SPD_WARP	        0x00000040 /* Use 460800 instead of 38400 bps*/
#define RPSHSI_SAK		0x00000080
#define RPSHSI_SESSION_LOCKOUT	0x00000100
#define RPSHSI_PGRP_LOCKOUT	0x00000200
	
#define RPSHSI_FLAGS		0x000003FF

#define RPSHSI_USR_MASK 0x0071	/* Legal flags that non-privileged
				 * users can set or reset */

/*
 * For closing_wait and closing_wait2
 */
#define RPSHSI_CLOSING_WAIT_NONE	65535
#define RPSHSI_CLOSING_WAIT_INF		0

/*
 * RPSH-SI State define's
 */
#define SI_STATE_RESET		 0
#define SI_STATE_BOOTING	 1
#define SI_STATE_BOOTED		 2
#define SI_STATE_CONNECTING	 3
#define SI_STATE_CONNECTING_WAIT 4
#define SI_STATE_CONNECTED	 5
#define SI_STATE_DEAD		 6

typedef struct {
  int sock;
  int msTimeout;
} tTcpTxQueueWait;

/*
 * Rocketport ioctls supported
 */
#define RPSHSI_LOAD_CODE4_8		0x00565301
#define RPSHSI_GET_CONFIG		0x00565302
#define RPSHSI_SET_CONFIG		0x00565303
#define RPSHSI_GET_CTL_MAJOR		0x00565304
#define RPSHSI_SET_BOX_CONFIG  		0x00565305
#define RPSHSI_GET_BOX_CONFIG		0x00565306
#define RPSHSI_GET_BOX_REPORT		0x00565307
#define RPSHSI_GET_PROBLEM_BOXES	0x00565308
#define RPSHSI_DEBUG_MISC		0x00565309
#define RPSHSI_SET_TCP	                0x0056530A
#define RPSHSI_LOAD_CODE2	        0x0056530B
#define RPSHSI_SET_MAC                  0x0056530C
#define RPSHSI_TCP_TXQUEUE_WAIT         0x0056530D
#define RPSHSI_FORCE_PORT_RELEASE       0x0056530E

